****************
Related Projects
****************

What other projects leverage ``xskillscore``?
---------------------------------------------
- `climpred <https://climpred.readthedocs.io>`_: Analysis of ensemble forecast models for climate prediction.
- `esmlab <https://esmlab.readthedocs.io>`_: Tools for working with earth system multi-model analyses with xarray.
- A `Google Colab notebook <https://colab.research.google.com/drive/1wWHz_SMCHNuos5fxWRUJTcB6wqkTJQCR>`_
  by `Matteo De Felice <https://github.com/matteodefelice>`_.
